# Bioez Package

## Installation: `pip install bioez`

## Usage: `from bioez import bz`

[Github](https://github.com/Rukhan4/bioezpkg)

## Package details

Contains several low level bioinformatics scripts to automate analysis tasks. It mainly runs on genomic and Dna data. 
These are stored in methods which are fully documented. 

Package Dependancies:

Random (built in)

Math (built in)